/**
 @param centers_pieces une liste des centres des pions sur l'aire de jeu
 @param centers_cases  une liste des centres des cases sur l'aire de jeu
 @return un tableau des positions déjà jouées
 */
int[] getPositionsPieces(ArrayList<PVector> centers_pieces, ArrayList<PVector> centers_boxes) {
  float surface = getSurfaceGrid();
  int[] njeu = new int[9];
  if (centers_pieces.isEmpty()) {
    njeu = initialiseJeu();
    jeu = initialiseJeu();
  }
  for (PVector p : centers_pieces) {
    for (PVector c : centers_boxes) {
      if (abs(dist(c.x, c.y, p.x, p.y)) <= sqrt(surface/9)/2 )
        njeu[centers_boxes.indexOf(c)]=1;
    }
  } 
  return njeu;
}

/**
 @param a Un point (x1, y1)
 @param b Un autre point (x2, y2)
 @param epsilon tolérance sur l'égalité de deux flottants
 @retrun vrai si : 
 a.y > b.y ou (a.y == b.y et a.x < b.x)
 */
boolean isSort(PVector a, PVector b, int epsilon) {
  if (a.y-b.y > epsilon || (a.y - b.y < epsilon && a.x < b.x) )
    return true;
  else
    return false;
}

/**
 @param pts une liste de points (x, y)
 @return une ArrayList de points triés selon un ordre décroissant
 sur la coordonnée y et croissant sur la coordonée x afin d'obtenir
 la grille de morpion suivante : 
 |1|2|3|
 |4|5|6|
 |7|8|9|
 */
ArrayList<PVector> sortPoints(ArrayList<PVector> pts) {
  int n = pts.size();
  int k;
  PVector tmp;
  for (int i=1; i<n; i++) {
    k = i;
    while (k!=0 && !isSort (pts.get (k-1), pts.get(k), 10)) {
      tmp = pts.get(k-1);
      pts.set(k-1, pts.get(k));
      pts.set(k, tmp);
      k = k-1;
    }
  }
  return pts;
}
/**
 Permet d'afficher sur la sortie standard les numéros des cases
 @param centers_boxes une liste des centres des cases du plateau de jeu
 **/
void drawBoxesNumbers(ArrayList<PVector> centers_boxes) {
  for (PVector c : centers_boxes) {
    fill(255, 0, 0);
    textSize(20);
    text( Integer.toString(centers_boxes.indexOf(c)), c.x, c.y);
  }
}

